/*******************************************************************************
 * Copyright (c) 2016, 2018 fortiss GmbH.
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v2.0 which is available at
 * http://www.eclipse.org/legal/epl-v20.html
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Florian Hoelzl (fortiss GmbH) - initial implementation
 *
 *******************************************************************************/
package org.fortiss.tooling.common.ui.javafx.control.treetableview;

import javafx.scene.Node;
import javafx.scene.control.ContextMenu;

/**
 * This UI provider is responsible to return the label, the icon, and the context menu for each cell
 * in the {@link DynamicTreeTableViewer} based on the data object and the column.
 */
public abstract class DynamicTreeTableUIProviderBase {
	/**
	 * @param element
	 *            the element to be displayed in the current row
	 * @param column
	 *            the current column
	 * @return the label to be displayed in the given column
	 */
	public String getLabel(Object element, int column) {
		return "";
	}

	/**
	 * @param element
	 *            the element to be displayed in the current row
	 * @param column
	 *            the current column
	 * @return the node to be displayed as the icon in the given column
	 */
	public Node getIconNode(Object element, int column) {
		return null;
	}

	/**
	 * @param element
	 *            the element to be displayed in the current row
	 * @param column
	 *            the current column
	 * @return the context menu in the given column
	 */
	public ContextMenu createContextMenu(Object element, int column) {
		return null;
	}
}
